@@ -6,10 +6,10 @@ from sentry_sdk.integrations.aiohttp import AioHttpIntegration
 from sentry_sdk.integrations.logging import LoggingIntegration
 from sentry_sdk.integrations.sqlalchemy import SqlalchemyIntegration
 
-from PyDrocsid.environment import LOG_LEVEL
+from PyDrocsid.environment import LOG_LEVEL, PYCORD_LOG_LEVEL
 
 
-def setup_sentry(dsn: str, name: str, version: str):
+def setup_sentry(dsn: str, name: str, version: str) -> None:
     """Initialize sentry connection."""
 
     sentry_sdk.init(
@@ -19,10 +19,7 @@ def setup_sentry(dsn: str, name: str, version: str):
         integrations=[
             AioHttpIntegration(),
             SqlalchemyIntegration(),
-            LoggingIntegration(
-                level=logging.DEBUG,
-                event_level=logging.WARNING,
-            ),
+            LoggingIntegration(level=logging.DEBUG, event_level=logging.WARNING),
         ],
         release=f"{name}@{version}",
     )
@@ -42,3 +39,6 @@ def get_logger(name: str) -> logging.Logger:
     logger.setLevel(LOG_LEVEL.upper())
 
     return logger
+
+
+get_logger("discord").setLevel(PYCORD_LOG_LEVEL.upper())
